from pyroute2.common import dqn2int, hexdump, hexload, uifname, uuid32


def test_hexdump():
    binary = b'abcdef5678'
    dump1 = hexdump(binary)
    dump2 = hexdump(binary, length=6)
    assert len(dump1) == 29
    assert len(dump2) == 17
    assert dump1[2] == dump1[-3] == dump2[2] == dump2[-3] == ':'
    assert hexload(dump1) == binary
    assert hexload(dump2) == binary[:6]


def test_uuid32():
    uA = uuid32()
    uB = uuid32()
    prime = __builtins__.get('long', int)
    assert isinstance(uA, prime)
    assert isinstance(uB, prime)
    assert uA != uB
    assert uA < 0x100000000
    assert uB < 0x100000000


def test_dqn2int():
    assert dqn2int('255.255.255.0') == 24
    assert dqn2int('255.240.0.0') == 12
    assert dqn2int('255.0.0.0') == 8


def test_uifname():
    nA = uifname()
    nB = uifname()
    assert nA != nB
    assert int(nA[2:], 16) != int(nB[2:], 16)



from pyroute2 import IPRoute

ipr = IPRoute()

print('iterate network interfaces\n')
for msg in ipr.get_links():
    # using dict API
    print('interface index:', msg['index'])
    # using .get_attr()
    print('interface name:', msg.get_attr('IFLA_IFNAME'))
    # using .get()
    print('forwarding flag:', msg.get(('af_spec', 'af_inet', 'forwarding')))
    # using .get_nested()
    print('same with get_nested():',
        msg.get_nested('IFLA_AF_SPEC', 'AF_INET')['forwarding']
    )
    print('\nraw interface data\n', msg)

ipr.close()



import queue


class TaskRouter:

    def __init__(self, maxsize=None):
        self.queue = queue.Queue(maxsize=maxsize)
        self.routing = {}

    @classmethod
    def publish(cls, key, route):
        self.routing[key] = route

    def __next__(self):
        return self.queue.get()

    def __iter__(self):
        return self
